ket_process_set_parameter

Function ket_process_set_parameter 

#[unsafe(no_mangle)]
pub extern "C" fn ket_process_set_parameter( process: &mut Process, value: f64, index: &mut usize, ) -> i32
Registers a new parameter with the given initial value in the process.

The parameter’s index within the process parameter list is written to index.

Parameters

  • process: The process to register the parameter in.
  • value: The initial value of the parameter.
  • index: Output: set to the registered parameter’s index.

Returns

0 on success, non-zero error code on failure.