pub enum DecomposedGate {
U(QuantumGate, usize),
CNOT(usize, usize),
}Expand description
A primitive quantum gate resulting from the decomposition of a multi-controlled gate.
Multi-controlled gates are decomposed into a sequence of single-qubit gates
(DecomposedGate::U) and two-qubit CNOT gates (DecomposedGate::CNOT).
Variants
U(QuantumGate, usize)
A single-qubit gate instruction applied to a target qubit.
CNOT(usize, usize)
A CNOT gate instruction applied to a control and a target qubit.
Implementations