C API for interacting with Process operations.
Functions
- ket_
config_ new - Allocates a new
QPUConfigfor a QPU with the specified number of physical qubits. - ket_
process_ alloc - Allocates a new logical qubit in the process.
- ket_
process_ append_ block - Appends a
BasicBlockof gates to the process. - ket_
process_ delete - Deallocates the memory associated with a
Process. - ket_
process_ dump - Dumps the quantum state of
qubits(live mode only). - ket_
process_ execute - Compiles and executes the accumulated circuit.
- ket_
process_ exp_ value - Requests the expectation value computation for a given
Hamiltonian(passed as JSON) on aProcess. - ket_
process_ gates_ json - Returns the accumulated gate instructions of the process as a JSON string.
- ket_
process_ measure - Performs a single-shot mid-circuit measurement of
qubits. - ket_
process_ new - Allocates a new
Processusing the provided QPU configuration. - ket_
process_ param - Registers a new differentiable parameter with the given initial value.
- ket_
process_ read_ exp_ value - Returns a serialized JSON array of expectation values from the most recent execution.
- ket_
process_ read_ gradient - Returns a serialized JSON array of parameter-shift gradients from the most recent execution.
- ket_
process_ read_ sample - Reads the cached sample data from a
Process. - ket_
process_ sample - Requests a measurement sample of
qubitsovershotsrepetitions. - ket_
process_ set_ parameter - Registers a new parameter with the given initial value in the process.
- ket_
process_ status - Returns the current status of the process as a static C string.