pub type BitString = Vec<u64>;Expand description
A bit-string measurement outcome encoded as a vector of 64-bit words.
Each element in the outer Vec is one measurement shot; within a shot the
qubit outcomes are packed into 64-bit words (LSB = qubit 0).
Aliased Type
pub struct BitString { /* private fields */ }